@@ -20,8 +20,6 @@ def handle_log(log_path):
     kyAAT = logging.getLogger(name='kyAAT')
 
     pycharm = logging.StreamHandler()#控制台渠道
-    with open(log_dir, "w+") as f:
-        pass
     file = handlers.TimedRotatingFileHandler( filename=log_dir, when='D', encoding='utf-8',interval=1, backupCount=10)
 
     #日志格式
